@@ -19,10 +19,13 @@
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDebug>
+#include <QtCore/QDir>
 #include <QtCore/QString>
 #include <QtCore/QStringList>
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusConnectionInterface>
+#include <QtDBus/QDBusInterface>
+#include <QtDBus/QDBusReply>
 
 #include <config-akonadi.h>
 
@@ -53,6 +56,11 @@ static bool startServer()
 static bool stopServer()
 {
   org::freedesktop::Akonadi::ControlManager iface( AKONADI_DBUS_CONTROL_SERVICE, "/ControlManager", QDBusConnection::sessionBus(), 0 );
+  if ( !iface.isValid() ) {
+    qDebug( "Unable to connect to dbus interface of control service" );
+    return false;
+  }
+
   iface.shutdown();
 
   return true;
@@ -66,6 +74,29 @@ static bool statusServer()
   registered = QDBusConnection::sessionBus().interface()->isServiceRegistered( AKONADI_DBUS_SERVER_SERVICE );
   qDebug( "Akonadi Server: %s", registered ? "running" : "stopped" );
 
+  registered = QDBusConnection::sessionBus().interface()->isServiceRegistered( "org.kde.nepomuk.services.nepomukqueryservice" );
+  if ( registered ) {
+    QString backend = QLatin1String( "Unknown" );
+
+    // check which backend is used
+    QDBusInterface interface( "org.kde.NepomukStorage", "/nepomukstorage" );
+    const QDBusReply<QString> reply = interface.call( "usedSopranoBackend" );
+    if ( reply.isValid() ) {
+      const QString name = reply.value();
+
+      if ( name == QLatin1String( "redland" ) )
+        backend = QLatin1String( "Redland" );
+      else if ( name == QLatin1String( "sesame2" ) )
+        backend = QLatin1String( "Sesame2" );
+      else if ( name == QLatin1String( "virtuosobackend" ) )
+        backend = QLatin1String( "Virtuoso" );
+    }
+
+    qDebug( "Akonadi Server Search Support: available (backend: %s)", qPrintable( backend ) );
+  } else {
+    qDebug( "Akonadi Server Search Support: not available" );
+  }
+
   return true;
 }
 
