@@ -81,15 +81,15 @@ class AgentManager : public QObject
 
     /**
      * Returns the i18n'ed name of the agent type for
-     * the given @p identifier.
+     * the given @p identifier and the given @p language.
      */
-    QString agentName( const QString &identifier ) const;
+    QString agentName( const QString &identifier, const QString &language = QString("en_US") ) const;
 
     /**
      * Returns the i18n'ed comment of the agent type for
-     * the given @p identifier.
+     * the given @p identifier and the given @p language.
      */
-    QString agentComment( const QString &identifier ) const;
+    QString agentComment( const QString &identifier, const QString &language = QString("en_US") ) const;
 
     /**
      * Returns the icon name of the agent type for the
@@ -166,8 +166,10 @@ class AgentManager : public QObject
 
     /**
      * Returns the name of the agent instance with the given @p identifier.
+     * If there is no name, it returns the default name of the agent, you can tweak
+     * the language for that name with the @p language setting.
      */
-    QString agentInstanceName( const QString &identifier ) const;
+    QString agentInstanceName( const QString &identifier, const QString &language = QString( "en_US" ) ) const;
 
     /**
      * Triggers the agent instance with the given @p identifier to show
@@ -211,6 +213,16 @@ class AgentManager : public QObject
     */
     void restartAgentInstance( const QString &identifier );
 
+    /**
+     * Add a persistent search to remote search agents.
+     */
+    void addSearch( const QString &query, const QString &queryLanguage, qint64 resultCollectionId );
+
+    /**
+     * Removes a persistent search for the given result collection.
+     */
+    void removeSearch( quint64 resultCollectionId );
+
   Q_SIGNALS:
     /**
      * This signal is emitted whenever a new agent type was installed on the system.
@@ -329,6 +341,7 @@ class AgentManager : public QObject
     bool checkAgentExists( const QString &identifier ) const;
     void ensureAutoStart( const AgentType &info );
     void continueStartup();
+    void registerAgentAtServer( const AgentInstance::Ptr& instance, const AgentType& type );
 
   private:
     /**
