@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2006 Volker Krause <volker.krause@rwth-aachen.de>
+    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -27,14 +27,18 @@
 #include <storage/transaction.h>
 #include "abstractsearchmanager.h"
 #include "imapstreamparser.h"
+#include <storage/selectquerybuilder.h>
+#include <storage/collectionqueryhelper.h>
+#include "libs/protocol_p.h"
+#include <akdebug.h>
+
+#include <QDBusInterface>
 
 using namespace Akonadi;
 
-Delete::Delete() : Handler()
-{
-}
-
-Delete::~Delete()
+Delete::Delete( Scope scope ) :
+  Handler(),
+  m_scope( scope )
 {
 }
 
@@ -51,17 +55,23 @@ bool Delete::deleteRecursive(Collection & col)
 
 bool Delete::parseStream()
 {
-  QByteArray collectionByteArray = m_streamParser->readString();
+  m_scope.parseScope( m_streamParser );
+  SelectQueryBuilder<Collection> qb;
+  CollectionQueryHelper::scopeToQuery( m_scope, connection(), qb );
+  if ( !qb.exec() )
+    throw HandlerException( "Unable to execute collection query" );
+  const Collection::List collections = qb.result();
+  if ( collections.isEmpty() )
+    throw HandlerException( "No collection selected" );
+  else if ( collections.size() > 1 )
+    throw HandlerException( "Deleting multiple collections is not yet implemented" );
 
-  // prevent deletion of the root node
-  if ( collectionByteArray.isEmpty() )
-    return failureResponse( "Deleting everything is not allowed." );
 
   // check if collection exists
   DataStore *db = connection()->storageBackend();
   Transaction transaction( db );
 
-  Collection collection = HandlerHelper::collectionFromIdOrName( collectionByteArray );
+  Collection collection = collections.first();
   if ( !collection.isValid() )
     return failureResponse( "No such collection." );
 
@@ -71,8 +81,19 @@ bool Delete::parseStream()
     if ( collection.parentId() == 0 )
       return failureResponse( "Cannot delete virtual root collection" );
 
-    if ( !AbstractSearchManager::instance()->removeSearch( collection.id() ) )
-      return failureResponse( "Failed to remove search from search manager" );
+    AbstractSearchManager::instance()->removeSearch( collection.id() );
+
+    // disable remote searches
+    QDBusInterface agentMgr( QLatin1String( AKONADI_DBUS_CONTROL_SERVICE ),
+                             QLatin1String( AKONADI_DBUS_AGENTMANAGER_PATH ),
+                             QLatin1String( "org.freedesktop.Akonadi.AgentManagerInternal" ) );
+    if ( agentMgr.isValid() ) {
+      QList<QVariant> args;
+      args << collection.id();
+      agentMgr.callWithArgumentList( QDBus::NoBlock, QLatin1String( "removeSearch" ), args );
+    } else {
+      akError() << "Failed to connect to agent manager: " << agentMgr.lastError();
+    }
   }
 
   if ( !deleteRecursive( collection ) )
@@ -85,7 +106,6 @@ bool Delete::parseStream()
   response.setTag( tag() );
   response.setString( "DELETE completed" );
   emit responseAvailable( response );
-  deleteLater();
   return true;
 }
 
