@@ -20,6 +20,7 @@
 #include "scope.h"
 #include "imapstreamparser.h"
 #include "handler.h"
+#include "libs/protocol_p.h"
 
 #include <cassert>
 
@@ -46,11 +47,32 @@ void Scope::parseScope( ImapStreamParser* parser )
     }
     if ( mRidSet.isEmpty() )
       throw HandlerException( "Empty remote identifier set specified" );
+  } else if ( mScope == HierarchicalRid ) {
+    parser->beginList();
+    while ( !parser->atListEnd() ) {
+      parser->beginList();
+      parser->readString(); // uid, invalid here
+      mRidChain.append( parser->readUtf8String() );
+      if ( !parser->atListEnd() )
+        throw HandlerException( "Invalid hierarchical RID chain format" );
+    }
   } else {
     throw HandlerException( "WTF?!?" );
   }
 }
 
+Scope::SelectionScope Scope::selectionScopeFromByteArray(const QByteArray& input)
+{
+  if ( input == AKONADI_CMD_UID ) {
+    return Scope::Uid;
+  } else if ( input == AKONADI_CMD_RID ) {
+    return Scope::Rid;
+  } else if ( input == AKONADI_CMD_HRID ) {
+    return Scope::HierarchicalRid;
+  }
+  return Scope::None;
+}
+
 Scope::SelectionScope Scope::scope() const
 {
   return mScope;
@@ -66,12 +88,12 @@ ImapSet Scope::uidSet() const
   return mUidSet;
 }
 
-void Scope::setUidSet(const ImapSet& set)
-{
-  mUidSet = set;
-}
-
 QStringList Scope::ridSet() const
 {
   return mRidSet;
 }
+
+QStringList Scope::ridChain() const
+{
+  return mRidChain;
+}
