@@ -38,7 +38,8 @@ class Scope
       Invalid,
       None,
       Uid,
-      Rid
+      Rid,
+      HierarchicalRid
     };
 
     Scope( SelectionScope scope );
@@ -48,16 +49,23 @@ class Scope
     */
     void parseScope( ImapStreamParser *parser );
 
+    /**
+      Parse the selection scope identifier (UID, RID, HRID, etc.).
+      Returns None if @p input is not a selection scope.
+    */
+    static SelectionScope selectionScopeFromByteArray( const QByteArray &input );
+
     SelectionScope scope() const;
     void setScope( SelectionScope scope );
     ImapSet uidSet() const;
-    void setUidSet( const ImapSet &set );
     QStringList ridSet() const;
+    QStringList ridChain() const;
 
   private:
     SelectionScope mScope;
     ImapSet mUidSet;
     QStringList mRidSet;
+    QStringList mRidChain;
 };
 
 }
