@@ -17,9 +17,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+
 #include "akonadi.h"
 #include "akapplication.h"
-#include "akdbus.h"
 #include "akdebug.h"
 #include "akcrash.h"
 
@@ -29,34 +29,26 @@
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusConnectionInterface>
 #include <QtDBus/QDBusError>
-#include <QTimer>
 
 #include <cstdlib>
 
-#ifdef QT_STATICPLUGIN
-#include <QtPlugin>
-
-Q_IMPORT_PLUGIN( qsqlite3 )
-#endif
-
 namespace po = boost::program_options;
 
 void shutdownHandler( int )
 {
-  akDebug() << "Shutting down AkonadiServer...";
+  qDebug( "Shutting down AkonadiServer..." );
 
-  Akonadi::Server::AkonadiServer::instance()->quit();
+  Akonadi::AkonadiServer::instance()->quit();
 
   exit( 255 );
 }
 
 int main( int argc, char ** argv )
 {
-    Q_INIT_RESOURCE( akonadidb );
-    AkCoreApplication app( argc, argv );
+    AkApplication app( argc, argv );
     app.setDescription( QLatin1String( "Akonadi Server\nDo not run manually, use 'akonadictl' instead to start/stop Akonadi." ) );
 
-#if !defined(NDEBUG)
+#ifndef NDEBUG
     po::options_description debugOptions( "Debug options (use with care)" );
     debugOptions.add_options()
         ( "start-without-control", "Allow to start the Akonadi server even without the Akonadi control process being available" );
@@ -65,22 +57,21 @@ int main( int argc, char ** argv )
 
     app.parseCommandLine();
 
-   if ( !app.commandLineArguments().count( "start-without-control" ) &&
-        !QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName( AkDBus::ControlLock ) ) ) {
-     akError() << "Akonadi control process not found - aborting.";
-     akFatal() << "If you started akonadiserver manually, try 'akonadictl start' instead.";
-   }
+    if ( !app.commandLineArguments().count( "start-without-control" ) &&
+         !QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE) ) ) {
+      akError() << "Akonadi control process not found - aborting.";
+      akFatal() << "If you started akonadiserver manually, try 'akonadictl start' instead.";
+    }
 
-    // Make sure we do initialization from eventloop, otherwise
-    // org.freedesktop.Akonadi.upgrading service won't be registered to DBus at all
-    QTimer::singleShot(0, Akonadi::Server::AkonadiServer::instance(), SLOT(init()));
+    Akonadi::AkonadiServer::instance(); // trigger singleton creation
     AkonadiCrash::setShutdownMethod( shutdownHandler );
 
+    if ( !QDBusConnection::sessionBus().registerService( QLatin1String(AKONADI_DBUS_SERVER_SERVICE) ) )
+      akFatal() << "Unable to connect to dbus service: " << QDBusConnection::sessionBus().lastError().message();
+
     const int result = app.exec();
 
-    Akonadi::Server::AkonadiServer::instance()->quit();
-
-    Q_CLEANUP_RESOURCE( akonadidb );
+    Akonadi::AkonadiServer::instance()->quit();
 
     return result;
 }
