@@ -22,8 +22,6 @@
 
 #include <QtCore/QObject>
 
-#include "agentmanagerinterface.h"
-
 namespace Akonadi {
 
 /**
@@ -41,12 +39,11 @@ class ResourceManager : public QObject
     ResourceManager( QObject *parent = 0 );
 
   public Q_SLOTS:
-    bool addResourceInstance( const QString &name );
-    bool removeResourceInstance( const QString &name );
+    void addResourceInstance( const QString &name, const QStringList &capabilites );
+    void removeResourceInstance( const QString &name );
 
   private:
     static ResourceManager* mSelf;
-    org::freedesktop::Akonadi::AgentManager *mManager;
 };
 
 }
