@@ -64,7 +64,7 @@ DataStore::DataStore() :
   open();
 
   m_transactionLevel = 0;
-  NotificationManager::self()->connectDatastore( this );
+  NotificationManager::self()->connectNotificationCollector( mNotificationCollector );
 }
 
 DataStore::~DataStore()
