@@ -115,15 +115,10 @@ class AKONADIPRIVATE_EXPORT DataStore : public QObject
     */
     static DataStore* self();
 
-    /* --- Flag ---------------------------------------------------------- */
-    bool appendFlag( const QString & name );
-
     /* --- ItemFlags ----------------------------------------------------- */
     bool setItemFlags( const PimItem &item, const QList<Flag> &flags );
     bool appendItemFlags( const PimItem &item, const QList<Flag> &flags,
                           bool checkIfExists = true, const Collection &col = Collection() );
-    bool appendItemFlags( const PimItem &item, const QList<QByteArray> &flags,
-                          bool checkIfExists = true, const Collection &col = Collection() );
     bool removeItemFlags( const PimItem &item, const QList<Flag> &flags );
 
     /* --- ItemParts ----------------------------------------------------- */
@@ -133,8 +128,8 @@ class AKONADIPRIVATE_EXPORT DataStore : public QObject
     bool appendCollection( Collection &collection );
     /// removes the given collection and all its content
     bool cleanupCollection( Collection &collection );
-    /// rename the collection @p collection to @p newName.
-    bool renameCollection( Collection &collection, qint64 newParent, const QByteArray &newName );
+    /// moves the collection @p collection to @p newParent.
+    bool moveCollection( Akonadi::Collection& collection, const Akonadi::Collection& newParent );
 
     bool appendMimeTypeForCollection( qint64 collectionId, const QStringList & mimeTypes );
 
@@ -167,6 +162,27 @@ class AKONADIPRIVATE_EXPORT DataStore : public QObject
      */
     bool cleanupPimItems( const Collection &collection );
 
+    /**
+     * Unhides the specified PimItem. Emits the itemAdded() notification as 
+     * the hidden flag is assumed to have been set by appendPimItem() before
+     * pushing the item to the preprocessor chain. The hidden item had his
+     * notifications disabled until now (so for the clients the "unhide" operation
+     * is actually a new item arrival).
+     *
+     * This function does NOT verify if the item was *really* hidden: this is
+     * responsability of the caller.
+     */
+    bool unhidePimItem( PimItem &pimItem );
+
+    /**
+     * Unhides all the items which have the "hidden" flag set.
+     * This function doesn't emit any notification about the items
+     * being unhidden so it's meant to be called only in rare circumstances.
+     * The most notable call to this function is at server startup
+     * when we attempt to restore a clean state of the database.
+     */
+    bool unhideAllPimItems();
+
     qint64 highestPimItemId() const;
 
     /* --- Collection attributes ------------------------------------------ */
@@ -237,13 +253,6 @@ protected:
 
     void debugLastDbError( const char* actionDescription ) const;
     void debugLastQueryError( const QSqlQuery &query, const char* actionDescription ) const;
-  public:
-    /** Returns the id of the most recent inserted row, or -1 if there's no such
-        id.
-        @param query the query we want to get the last insert id for
-        @return id of the most recent inserted row, or -1
-     */
-    static qint64 lastInsertId( const QSqlQuery & query );
 
   private:
     /** Converts the given date/time to the database format, i.e.
