@@ -68,8 +68,10 @@ class DbConfigStatic
 
       // determine default settings depending on the driver
       QString defaultDbName;
+      QString defaultHostName;
       QString defaultOptions;
       QString defaultServerPath;
+      QString defaultCleanShutdownCommand;
 
       if ( mDriverName == QLatin1String( "QMYSQL" ) ) {
         defaultDbName = QLatin1String( "akonadi" );
@@ -81,15 +83,22 @@ class DbConfigStatic
 #ifdef MYSQLD_EXECUTABLE
         defaultServerPath = QLatin1String( MYSQLD_EXECUTABLE );
 #endif
+        const QStringList mysqldSearchPath = QStringList()
+            << QLatin1String("/usr/sbin")
+            << QLatin1String("/usr/local/sbin")
+            << QLatin1String("/usr/local/libexec")
+            << QLatin1String("/usr/libexec")
+            << QLatin1String("/opt/mysql/libexec")
+            << QLatin1String("/opt/local/lib/mysql5/bin");
         if ( defaultServerPath.isEmpty() ) {
-          const QStringList mysqldSearchPath = QStringList()
-              << QLatin1String("/usr/sbin")
-              << QLatin1String("/usr/local/sbin")
-              << QLatin1String("/usr/local/libexec")
-              << QLatin1String("/usr/libexec")
-              << QLatin1String("/opt/mysql/libexec");
           defaultServerPath = XdgBaseDirs::findExecutableFile( QLatin1String("mysqld"), mysqldSearchPath );
         }
+        const QString mysqladminPath = XdgBaseDirs::findExecutableFile( QLatin1String("mysqladmin"), mysqldSearchPath );
+        if ( !mysqladminPath.isEmpty() ) {
+          defaultCleanShutdownCommand = QString::fromLatin1("%1 shutdown --socket=%2/mysql.socket")
+                                            .arg(mysqladminPath)
+                                            .arg(XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) ) );
+        }
         mInternalServer = settings.value( QLatin1String("QMYSQL/StartServer"), defaultInternalServer ).toBool();
         if ( mInternalServer ) {
           const QString miscDir = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) );
@@ -100,16 +109,35 @@ class DbConfigStatic
         defaultOptions = QString::fromLatin1( "SERVER_DATADIR=%1" ).arg( mysqlEmbeddedDataDir() );
       } else if ( mDriverName == QLatin1String( "QSQLITE" ) ) {
         defaultDbName = sqliteDataFile();
+      } else if ( mDriverName == QLatin1String( "QPSQL" ) ) {
+#ifndef Q_WS_WIN // We assume that PostgreSQL is running as service on Windows
+        const bool defaultInternalServer = true;
+#else
+        const bool defaultInternalServer = false;
+#endif
+        defaultDbName = QLatin1String( "akonadi" );
+
+        mInternalServer = settings.value( QLatin1String( "QPSQL/StartServer" ), defaultInternalServer ).toBool();
+        if ( mInternalServer ) {
+          const QStringList postgresSearchPath = QStringList()
+            << QLatin1String( "/usr/sbin" )
+            << QLatin1String( "/usr/local/sbin" )
+            << QLatin1String( "/usr/lib/postgresql/8.4/bin" );
+
+          defaultServerPath = XdgBaseDirs::findExecutableFile( QLatin1String( "postgres" ), postgresSearchPath );
+          defaultHostName = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) );
+        }
       }
 
       // read settings for current driver
       settings.beginGroup( mDriverName );
       mName = settings.value( QLatin1String( "Name" ), defaultDbName ).toString();
-      mHostName = settings.value( QLatin1String( "Host" ) ).toString();
+      mHostName = settings.value( QLatin1String( "Host" ), defaultHostName ).toString();
       mUserName = settings.value( QLatin1String( "User" ) ).toString();
       mPassword = settings.value( QLatin1String( "Password" ) ).toString();
       mConnectionOptions = settings.value( QLatin1String( "Options" ), defaultOptions ).toString();
       mServerPath = settings.value( QLatin1String("ServerPath"), defaultServerPath ).toString();
+      mCleanServerShutdownCommand = settings.value( QLatin1String("CleanServerShutdownCommand"), defaultCleanShutdownCommand ).toString();
       settings.endGroup();
 
       // verify settings and apply permanent changes (written out below)
@@ -126,6 +154,7 @@ class DbConfigStatic
       settings.setValue( QLatin1String( "General/ExternalPayload" ), mUseExternalPayloadFile );
       settings.beginGroup( mDriverName );
       settings.setValue( QLatin1String( "Name" ), mName );
+      settings.setValue( QLatin1String( "Host" ), mHostName );
       settings.setValue( QLatin1String( "User" ), mUserName );
       settings.setValue( QLatin1String( "Password" ), mPassword );
       settings.setValue( QLatin1String( "Options" ), mConnectionOptions );
@@ -208,6 +237,7 @@ class DbConfigStatic
     bool mInternalServer;
     bool mUseExternalPayloadFile;
     qint64 mSizeThreshold;
+    QString mCleanServerShutdownCommand;
 };
 
 Q_GLOBAL_STATIC( DbConfigStatic, sInstance )
@@ -264,3 +294,8 @@ bool DbConfig::useExternalPayloadFile()
   return sInstance()->mUseExternalPayloadFile;
 }
 
+QString DbConfig::cleanServerShutdownCommand()
+{
+    return sInstance()->mCleanServerShutdownCommand;
+}
+
