@@ -33,11 +33,7 @@ void ItemQueryHelper::itemSetToQuery(const ImapSet& set, QueryBuilder& qb, const
 {
   QueryHelper::setToQuery( set, PimItem::idFullColumnName(), qb );
   if ( collection.isValid() ) {
-    // FIXME: we probably want to do both paths here in all cases, but that is apparently
-    // non-trivial with SQL
-    if ( collection.resource().name() == QLatin1String("akonadi_search_resource") ||
-      collection.resource().name().contains( QLatin1String("nepomuk") ) )
-    {
+    if ( collection.resource().isVirtual() ) {
       qb.addTable( CollectionPimItemRelation::tableName() );
       qb.addValueCondition( CollectionPimItemRelation::leftFullColumnName(), Query::Equals, collection.id() );
       qb.addColumnCondition( CollectionPimItemRelation::rightFullColumnName(), Query::Equals,
@@ -63,13 +59,13 @@ void ItemQueryHelper::remoteIdToQuery(const QStringList& rids, AkonadiConnection
   else
     qb.addValueCondition( PimItem::remoteIdFullColumnName(), Query::In, rids );
 
-  if ( connection->selectedCollectionId() > 0 ) {
-    qb.addTable( Collection::tableName() );
-    qb.addValueCondition( PimItem::collectionIdFullColumnName(), Query::Equals, connection->selectedCollectionId() );
-  } else if ( connection->resourceContext().isValid() ) {
+  if ( connection->resourceContext().isValid() ) {
     qb.addTable( Collection::tableName() );
     qb.addColumnCondition( PimItem::collectionIdFullColumnName(), Query::Equals, Collection::idFullColumnName() );
     qb.addValueCondition( Collection::resourceIdFullColumnName(), Query::Equals, connection->resourceContext().id() );
+  } else if ( connection->selectedCollectionId() > 0 ) {
+    qb.addTable( Collection::tableName() );
+    qb.addValueCondition( PimItem::collectionIdFullColumnName(), Query::Equals, connection->selectedCollectionId() );
   }
 }
 
