@@ -25,66 +25,60 @@
 #include <QBuffer>
 
 #include "imapstreamparser.h"
-#include <aktest.h>
-#include <config-akonadi.h>
 
 Q_DECLARE_METATYPE( QList<QByteArray> )
 Q_DECLARE_METATYPE( QList<int> )
 
 using namespace Akonadi;
-using namespace Akonadi::Server;
 
-#if 0
 QString akBacktrace()
 {
   QString s;
 
   /* FIXME: is there an equivalent for darwin, *BSD, or windows? */
-#ifdef Backtrace_FOUND
-  void *trace[256];
-  int n = backtrace( trace, 256 );
-  if ( !n ) {
+#ifdef HAVE_EXECINFO_H
+  void* trace[256];
+  int n = backtrace(trace, 256);
+  if (!n)
     return s;
-  }
 
-  char **strings = backtrace_symbols( trace, n );
+  char** strings = backtrace_symbols (trace, n);
 
-  s = QLatin1String( "[\n" );
+  s = QLatin1String("[\n");
 
   for ( int i = 0; i < n; ++i ) {
-    s += QString::number( i ) +
-        QLatin1String( ": " ) +
-        QLatin1String( strings[i] ) + QLatin1String( "\n" );
+    s += QString::number(i) +
+        QLatin1String(": ") +
+        QLatin1String(strings[i]) + QLatin1String("\n");
   }
-  s += QLatin1String( "]\n" );
+  s += QLatin1String("]\n");
 
-  if ( strings ) {
-    free( strings );
-  }
+  if (strings)
+    free (strings);
 #endif
 
   return s;
 }
-#endif
 
-AKTEST_MAIN( ImapStreamParserTest )
+QTEST_MAIN( ImapStreamParserTest )
 
-void ImapStreamParserTest::testParseQuotedString()
+
+void ImapStreamParserTest::testParseQuotedString( )
 {
   QByteArray result;
 
   QBuffer buffer;
-  buffer.open( QBuffer::ReadWrite );
-  ImapStreamParser parser( &buffer );
+  buffer.open( QBuffer::ReadWrite);
+  ImapStreamParser parser(&buffer);
   buffer.write( QByteArray( "\"quoted \\\"NIL\\\"   string inside\"" ) );
-  buffer.write( QByteArray( "quoted" ) );
+  buffer.write( QByteArray( "quoted") );
   buffer.write( QByteArray( "\"   string inside\"" ) );
   buffer.write( QByteArray( "   string " ) );
-  buffer.write( "NIL \"NIL\" \"\"" );
+  buffer.write("NIL \"NIL\" \"\"");
   buffer.write( " string" );
   buffer.write( "\"\\\"some \\\\ quoted stuff\\\"\"" );
   buffer.write( "LOGOUT\nFOO" );
-  buffer.seek( 0 );
+  buffer.seek(0);
 
   try {
   // the whole thing
@@ -103,6 +97,7 @@ void ImapStreamParserTest::testParseQuotedString()
   result = parser.parseQuotedString();
   QCOMPARE( result, QByteArray( "string" ) );
 
+
   // NIL and emptyness tests
 
   // unqoted NIL
@@ -131,21 +126,22 @@ void ImapStreamParserTest::testParseQuotedString()
 
   // linebreak as separator
   result = parser.parseQuotedString();
-  QCOMPARE( result, QByteArray( "LOGOUT" ) );
-  } catch ( const Akonadi::Server::Exception &e ) {
+  QCOMPARE( result, QByteArray("LOGOUT") );
+  } catch ( const Akonadi::Exception &e ) {
     qDebug() << "Caught exception: " << e.type() << " : " << e.what();
   }
 }
 
-void ImapStreamParserTest::testParseString()
+
+void ImapStreamParserTest::testParseString( )
 {
 
   QBuffer buffer;
-  buffer.open( QBuffer::ReadWrite );
-  ImapStreamParser parser( &buffer );
+  buffer.open( QBuffer::ReadWrite);
+  ImapStreamParser parser(&buffer);
 
   buffer.write( QByteArray( "\"quoted\" unquoted {7}\nliteral {0}\n " ) );
-  buffer.seek( 0 );
+  buffer.seek(0);
 
   QByteArray result;
   bool exceptionExpected = false;
@@ -158,15 +154,15 @@ void ImapStreamParserTest::testParseString()
   QCOMPARE( result, QByteArray( "quoted" ) );
 
   // unquoted string
-  result = parser.peekString();
+  result = parser.peekString( );
   QCOMPARE( result, QByteArray( "unquoted" ) );
-  result = parser.readString();
+  result = parser.readString( );
   QCOMPARE( result, QByteArray( "unquoted" ) );
 
   // literal string
-  result = parser.peekString();
+  result = parser.peekString( );
   QCOMPARE( result, QByteArray( "literal" ) );
-  result = parser.readString();
+  result = parser.readString( );
   QCOMPARE( result, QByteArray( "literal" ) );
 
   // empty literal string
@@ -181,75 +177,67 @@ void ImapStreamParserTest::testParseString()
   exceptionExpected = true;
   result = parser.readString();
   QCOMPARE( result, QByteArray() );
-  } catch ( const Akonadi::Server::Exception &e ) {
+  } catch ( const Akonadi::Exception &e ) {
     qDebug() << "Caught exception: " << e.type() << " : " << e.what();
     QVERIFY( exceptionExpected );
   }
 }
 
-void ImapStreamParserTest::testParseParenthesizedList()
+void ImapStreamParserTest::testParseParenthesizedList( )
 {
   QBuffer buffer;
-  buffer.open( QBuffer::ReadWrite );
-  ImapStreamParser parser( &buffer );
+  buffer.open( QBuffer::ReadWrite);
+  ImapStreamParser parser(&buffer);
 
   buffer.write( QByteArray( "() ( )" ) );
   buffer.write( QByteArray( "(entry1 \"entry2()\" (sub list) \")))\" {6}\nentry3) " ) );
   buffer.write( QByteArray( "some_list-less_text" ) );
-  buffer.write( QByteArray( "(foo {6}\n\n\nbar\n bla)" ) );
-  buffer.write( QByteArray( "(AA (\"BB)\" CC))" ) );    // parenthesis inside quoted string
-  buffer.seek( 0 );
+  buffer.write( QByteArray( "(foo {6}\n\n\nbar\n bla)" ));
+  buffer.seek(0);
 
   QList<QByteArray>result;
 
   try {
-    // empty lists
-    result = parser.readParenthesizedList();
-    QVERIFY( result.isEmpty() );
+  // empty lists
+  result = parser.readParenthesizedList();
+  QVERIFY( result.isEmpty() );
 
-    result = parser.readParenthesizedList();
-    QVERIFY( result.isEmpty() );
+  result = parser.readParenthesizedList();
+  QVERIFY( result.isEmpty() );
 
-    // complex list with all kind of entries
-    qDebug() << "complex test";
-    result = parser.readParenthesizedList();
-    QList<QByteArray> reference;
-    reference << "entry1";
-    reference << "entry2()";
-    reference << "(sub list)";
-    reference << ")))";
-    reference << "entry3";
+  // complex list with all kind of entries
+  qDebug() << "complex test";
+  result = parser.readParenthesizedList();
+  QList<QByteArray> reference;
+  reference << "entry1";
+  reference << "entry2()";
+  reference << "(sub list)";
+  reference << ")))";
+  reference << "entry3";
 
-    QCOMPARE( result, reference );
 
-    // no list at all
-    result = parser.readParenthesizedList();
-    QVERIFY( result.isEmpty() );
+  QCOMPARE( result, reference );
 
-    parser.readString(); //just to advance in the data
+  // no list at all
+  result = parser.readParenthesizedList(  );
+  QVERIFY( result.isEmpty() );
 
-//     // out of bounds access
-//     result = parser.readParenthesizedList( input, result, input.length() );
-//     QVERIFY( result.isEmpty() );
-//     QCOMPARE( consumed, input.length() );
+  parser.readString(); //just to advance in the data
 
-    // newline literal (based on itemappendtest bug)
-    result = parser.readParenthesizedList();
-    reference.clear();
-    reference << "foo";
-    reference << "\n\nbar\n";
-    reference << "bla";
+//   // out of bounds access
+//   result = parser.readParenthesizedList( input, result, input.length() );
+//   QVERIFY( result.isEmpty() );
+//   QCOMPARE( consumed, input.length() );
 
-    QCOMPARE( result, reference );
+  // newline literal (based on itemappendtest bug)
+  result = parser.readParenthesizedList(  );
+  reference.clear();
+  reference << "foo";
+  reference << "\n\nbar\n";
+  reference << "bla";
 
-    // Don't try to parse characters inside a quoted-string
-    result = parser.readParenthesizedList();
-    reference.clear();
-    reference << "AA";
-    reference << "(\"BB)\" CC)";
-
-    QCOMPARE( result, reference );
-  } catch ( const Akonadi::Server::Exception &e ) {
+  QCOMPARE( result, reference );
+  } catch ( const Akonadi::Exception &e ) {
     qDebug() << "Caught exception: " << e.type() << " : " <<
         e.what();
     QVERIFY( false );
@@ -283,7 +271,7 @@ void ImapStreamParserTest::testParseNumber()
 
   QBuffer buffer;
   buffer.open( QBuffer::ReadWrite | QIODevice::Truncate );
-  ImapStreamParser parser( &buffer );
+  ImapStreamParser parser(&buffer);
 
   buffer.write( input );
   buffer.seek( startIndex );
@@ -293,14 +281,14 @@ void ImapStreamParserTest::testParseNumber()
     qint64 number = parser.readNumber();
     QCOMPARE( number, result );
   } catch ( const ImapParserException &e ) {
-    if ( success ) {
+    if ( success )
       qDebug() << "Caught unexpected parser exception: " << " : " << e.what();
-    }
     failed = true;
   }
   QCOMPARE( failed, !success );
 }
 
+
 void ImapStreamParserTest::testParseSequenceSet_data()
 {
   QTest::addColumn<QByteArray>( "data" );
@@ -339,23 +327,24 @@ void ImapStreamParserTest::testParseSequenceSet()
   QFETCH( bool, exceptionExpected );
 
   QBuffer buffer;
-  buffer.open( QBuffer::ReadWrite );
-  ImapStreamParser parser( &buffer );
+  buffer.open( QBuffer::ReadWrite);
+  ImapStreamParser parser(&buffer);
   buffer.write( data );
-  buffer.seek( 0 );
+  buffer.seek(0);
 
   ImapSet res;
   bool exceptionCaught = false;
   try {
     res = parser.readSequenceSet();
     QCOMPARE( res.intervals(), result );
-  } catch ( const Akonadi::Server::Exception &e ) {
+  } catch ( const Akonadi::Exception &e ) {
     qDebug() << "Caught exception: " << e.type() << " : " << e.what();
     exceptionCaught = true;
   }
   QCOMPARE( exceptionCaught, exceptionExpected );
 }
 
+
 void ImapStreamParserTest::testParseDateTime_data()
 {
   QTest::addColumn<QByteArray>( "data" );
@@ -383,17 +372,17 @@ void ImapStreamParserTest::testParseDateTime()
   QFETCH( bool, exceptionExpected );
 
   QBuffer buffer;
-  buffer.open( QBuffer::ReadWrite );
-  ImapStreamParser parser( &buffer );
+  buffer.open( QBuffer::ReadWrite);
+  ImapStreamParser parser(&buffer);
   buffer.write( data );
-  buffer.seek( 0 );
+  buffer.seek(0);
 
   QDateTime actualResult;
   bool exceptionCaught = false;
   try {
     actualResult = parser.readDateTime();
     QCOMPARE( actualResult, result );
-  } catch ( const Akonadi::Server::Exception &e ) {
+  } catch ( const Akonadi::Exception &e ) {
     qDebug() << "Caught exception: " << e.type() << " : " << e.what();
     exceptionCaught = true;
   }
@@ -420,7 +409,7 @@ void ImapStreamParserTest::testReadUntilCommandEnd()
     QVERIFY( !parser.atCommandEnd() );
     parser.readUntilCommandEnd();
     QCOMPARE( parser.readString(), QByteArray( "3" ) );
-  } catch ( const Akonadi::Server::Exception &e ) {
+  } catch ( const Akonadi::Exception &e ) {
     qDebug() << e.type() << e.what();
     QFAIL( "Exception caught" );
   }
@@ -440,29 +429,11 @@ void ImapStreamParserTest::testReadUntilCommandEnd2()
     QCOMPARE( parser.readString(), QByteArray( "595" ) );
     QCOMPARE( parser.readUntilCommandEnd(), QByteArray( " MIMETYPE (message/rfc822 inode/directory) NAME \"child2\" REMOTEID \"{b42}\"\n" ) );
     QCOMPARE( parser.readString(), QByteArray( "NEXTCOMMAND" ) );
-  } catch ( const Akonadi::Server::Exception &e ) {
+  } catch ( const Akonadi::Exception &e ) {
     qDebug() << e.type() << e.what();
     QFAIL( "Exception caught" );
   }
 }
 
-void ImapStreamParserTest::testAbortCommand()
-{
-  QByteArray input( "12 UID STORE 63696 REV 2 (REMOTEID.SILENT \"225\" REMOTEREVISION.SILENT "" FLAGS.SILENT (\\SEEN ) PLD:HEAD.SILENT {2226}\nNEXTCOMMAND " );
-  QBuffer buffer( &input, this );
-  buffer.open( QIODevice::ReadOnly );
-  ImapStreamParser parser( &buffer );
 
-  try {
-    // read some stuff and then notice that we can't process the command and abort early
-    QCOMPARE( parser.readString(), QByteArray( "12" ) );
-    QCOMPARE( parser.readString(), QByteArray( "UID" ) );
-    QCOMPARE( parser.readString(), QByteArray( "STORE" ) );
-    qDebug() << "!!!";
-    parser.skipCurrentCommand();
-    QCOMPARE( parser.readString(), QByteArray( "NEXTCOMMAND" ) );
-  } catch ( const Akonadi::Server::Exception &e ) {
-    qDebug() << e.type() << e.what();
-    QFAIL( "Exception caught" );
-  }
-}
+#include "imapstreamparsertest.moc"
