@@ -18,8 +18,8 @@
     02110-1301, USA.
 */
 
-#ifndef IMAPSTREAMPARSERTEST_H
-#define IMAPSTREAMPARSERTEST_H
+#ifndef IMAPPARSER_TEST_H
+#define IMAPPARSER_TEST_H
 
 #include <QtCore/QObject>
 #include <QtTest/QtTest>
@@ -39,8 +39,8 @@ class ImapStreamParserTest : public QObject
     void testParseDateTime();
     void testReadUntilCommandEnd();
     void testReadUntilCommandEnd2();
-    void testAbortCommand();
 
 };
 
+
 #endif
